<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.Management.Deployment

Windows Runtime (WinRT) APIs for for the `Windows.Phone.Management.Deployment` namespace.

This package provides the `winrt.windows.phone.management.deployment` module.
